[![Build/Test Check](https://github.com/cs481-ekh/f22-dust-devils/actions/workflows/ci.yml/badge.svg)](https://github.com/cs481-ekh/f22-dust-devils/actions/workflows/ci.yml) [![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)



<p align="center"><img src="docs/Muldoon.png" alt="Clever whirl." width="500"/></p>

# Muldoon, the vortex hunter

A package for sifting meteorological data to look for and analyze vortex encounters
